<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class emailmng_admin extends MX_Controller
{

    public function __construct()
    {
        parent::__construct();
        $this->load->config('emailmng/config');
        
        // Load language file
        $this->load->library('gettext_language');
        $this->gettext_language->load(__DIR__ . '/../language/' . $this->config->item('language') . '.po');
    }

    public function index()
    {
        $this->load->model('emailmng/crud_emailmng');

        return array('content' => $this->crud_emailmng->render(), 'title' => $this->lang->line('Templates'));
    }

    public function configuration()
    {
        $this->load->model('emailmng/emailmng_config');

        return array('content' => $this->emailmng_config->render(), 'title' => $this->lang->line('Configuration'));
    }

}
