CREATE TABLE IF NOT EXISTS `emailmng` ( 
`id_emailmng` int(11) NOT NULL AUTO_INCREMENT,
`code` varchar(255) CHARACTER SET utf8 NOT NULL,
`copy_to` varchar(255) CHARACTER SET utf8 NOT NULL,
`hidden_copy_to` varchar(255) CHARACTER SET utf8 NOT NULL,
`subject` varchar(255) CHARACTER SET utf8,
`message` text,
`mailtype` int(11),
PRIMARY KEY (`id_emailmng`) 
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
